@@ -21,41 +21,37 @@
 #include "bombitem.h"
 #include "cell.h"
 
-#include <QPixmapCache>
+#include <QGraphicsScene>
+#include <QGraphicsView>
+#include <KGameRenderer>
 
-BombExplosionItem::BombExplosionItem(Bomb* p_model, Direction direction, int bombPower, QPixmapCache* sharedPixmapCache, qreal svgScaleFactor) : QGraphicsPixmapItem()
+BombExplosionItem::BombExplosionItem(Bomb* p_model, Direction direction, int bombPower, KGameRenderer* renderer, qreal svgScaleFactor) : KGameRenderedItem(renderer, "")
 {
     m_direction = direction;
     m_explosionID = p_model->explosionID();
     
-    m_sharedPixmapCache = sharedPixmapCache;
     m_svgScaleFactor = svgScaleFactor;
     
     QString strElemetId;
     switch(m_direction)
     {
         case NORTH:
-            strElemetId = QString("bomb_blast_north_0");
+            setSpriteKey("bomb_blast_north_0");
             break;
         case EAST:
-            strElemetId = QString("bomb_blast_east_0");
+            setSpriteKey("bomb_blast_east_0");
             break;
         case SOUTH:
-            strElemetId = QString("bomb_blast_south_0");
+            setSpriteKey("bomb_blast_south_0");
             break;
         case WEST:
-            strElemetId = QString("bomb_blast_west_0");
+            setSpriteKey("bomb_blast_west_0");
             break;
     }
-
-    QPixmap pixmap;
-    m_pixmapMissing = !m_sharedPixmapCache->find(strElemetId, &pixmap);
-    if(!m_pixmapMissing)
-    {
-        setPixmap(pixmap);
-        setScale(m_svgScaleFactor);
-        setVisible(true);
-    }
+    
+    QSize svgSize = renderer->boundsOnSprite(spriteKey()).size().toSize() / m_svgScaleFactor;
+    setRenderSize(svgSize);
+    setScale(m_svgScaleFactor);
 }
 
 BombExplosionItem::~BombExplosionItem()
@@ -67,7 +63,7 @@ QPainterPath BombExplosionItem::shape() const
     QPainterPath path;
     // Temporary variable to keep the boundingRect available
     QRectF rect = boundingRect();
-
+    
     // Calculation of the shape
     QRectF shapeRect = QRectF(rect.x(), rect.y(), rect.width(), rect.height());
     path.addEllipse(shapeRect);
@@ -87,23 +83,23 @@ void BombExplosionItem::setPosition(qreal p_x, qreal p_y)
     switch(m_direction)
     {
         case NORTH:
-            x = p_x - boundingRect().width() * m_svgScaleFactor / 2;
-            y = p_y - (Cell::SIZE) + 20;
+            x = p_x - renderer()->boundsOnSprite(spriteKey()).width() / 2;
+            y = p_y - Cell::SIZE/2;
             setPos(x, y);
             break;
         case EAST:
-            x = p_x - (Cell::SIZE/2) - 20;
-            y = p_y - boundingRect().height() * m_svgScaleFactor / 2;
+            x = p_x - Cell::SIZE;
+            y = p_y - renderer()->boundsOnSprite(spriteKey()).height() / 2;
             setPos(x, y);
             break;
         case SOUTH:
-            x = p_x - boundingRect().width() * m_svgScaleFactor / 2;
-            y = p_y - (Cell::SIZE/2) - 20;
+            x = p_x - renderer()->boundsOnSprite(spriteKey()).width() / 2;
+            y = p_y - Cell::SIZE;
             setPos(x, y);
             break;
         case WEST:
-            x = p_x - (Cell::SIZE) + 20;
-            y = p_y - boundingRect().height() * m_svgScaleFactor / 2;
+            x = p_x - Cell::SIZE/2;
+            y = p_y - renderer()->boundsOnSprite(spriteKey()).height() / 2;
             setPos(x, y);
             break;
     }
@@ -115,28 +111,35 @@ void BombExplosionItem::updateAnimationn(int nFrame)
     switch(m_direction)
     {
         case NORTH:
-            strElemetId = QString("bomb_blast_north_%1").arg(nFrame);
+            setSpriteKey(QString("bomb_blast_north_%1").arg(nFrame));
             break;
         case EAST:
-            strElemetId = QString("bomb_blast_east_%1").arg(nFrame);
+            setSpriteKey(QString("bomb_blast_east_%1").arg(nFrame));
             break;
         case SOUTH:
-            strElemetId = QString("bomb_blast_south_%1").arg(nFrame);
+            setSpriteKey(QString("bomb_blast_south_%1").arg(nFrame));
             break;
         case WEST:
-            strElemetId = QString("bomb_blast_west_%1").arg(nFrame);
+            setSpriteKey(QString("bomb_blast_west_%1").arg(nFrame));
             break;
     }
-    
-    QPixmap pixmapNew;
-    if(m_sharedPixmapCache->find(strElemetId, &pixmapNew))
-    {
-        setPixmap(pixmapNew);
-        setScale(m_svgScaleFactor);
-    }
 }
 
-bool BombExplosionItem::pixmapMissing()
+void BombExplosionItem::updateGraphics(qreal svgScaleFactor)
 {
-    return m_pixmapMissing;
+    QSize svgSize = renderer()->boundsOnSprite(spriteKey()).size().toSize();
+    
+    QPoint topLeft(0, 0);
+    topLeft = scene()->views().at(0)->mapFromScene(topLeft);
+    
+    QPoint bottomRight(svgSize.width(), svgSize.height()); 
+    bottomRight = scene()->views().at(0)->mapFromScene(bottomRight);
+    
+    svgSize.setHeight(bottomRight.y() - topLeft.y());
+    svgSize.setWidth(bottomRight.x() - topLeft.x());
+    
+    //TODO: squeeze into a hard pixel grid
+    //m_arenaItem[i][j]->setRenderSize(QSize(Cell::SIZE / m_SvgScaleFactor, Cell::SIZE / m_SvgScaleFactor));
+    setRenderSize(svgSize);
+    setScale(svgScaleFactor);
 }
