@@ -24,6 +24,7 @@
 #include <QSignalMapper>
 #include <QShortcut>
 #include <QKeySequence>
+#include <QKeyEvent>
 
 #include <kglobal.h>
 #include <kstatusbar.h>
@@ -63,7 +64,7 @@ KGoldrunner::KGoldrunner()
 /*************  FIND WHERE THE GAMES DATA AND HANDBOOK SHOULD BE  *************/
 /******************************************************************************/
 
-    setObjectName ("KGoldrunner");
+    setObjectName ( QLatin1String("KGoldrunner" ));
 
     // Avoid "saveOK()" check if an error-exit occurs during the file checks.
     startupOK = true;
@@ -79,7 +80,7 @@ KGoldrunner::KGoldrunner()
     fprintf (stderr,
         "The games data and handbook should be in the following locations:\n");
     fprintf (stderr, "System games: %s\nUser data:    %s\nHandbook:     %s\n",
-        systemDataDir.myStr(), userDataDir.myStr(), systemHTMLDir.myStr());
+        qPrintable(systemDataDir), qPrintable(userDataDir), qPrintable(systemHTMLDir));
 
 /******************************************************************************/
 /************************  SET PLAYFIELD AND GAME DATA  ***********************/
@@ -115,7 +116,7 @@ KGoldrunner::KGoldrunner()
 /******************************************************************************/
 
     // Get catalog for translation.
-    KGlobal::locale()->insertCatalog ("libkdegames");
+    KGlobal::locale()->insertCatalog ( QLatin1String( "libkdegames" ));
 
     // Tell the KMainWindow that the KGrCanvas object is the main widget.
     setCentralWidget (view);
@@ -157,9 +158,6 @@ KGoldrunner::KGoldrunner()
     // Besides, we cannot render it until after the initial resize event (s).
     toolBar ("editToolbar")->hide();
 
-    // Set mouse control of the hero as the default.
-    game->settings (MOUSE);
-
     // Do NOT paint main widget yet (title, menu, status bar, blank playfield).
     // Instead, queue a call to the "KGoldrunner_2" constructor extension.
     QMetaObject::invokeMethod (this, "KGoldrunner_2", Qt::QueuedConnection);
@@ -309,14 +307,14 @@ void KGoldrunner::setupActions()
                                i18n ("&Create Level"),
                                i18n ("Create level."),
                                i18n ("Create a completely new level."));
-    ed->setIcon (KIcon ("document-new"));
+    ed->setIcon (KIcon ( QLatin1String( "document-new" )));
     ed->setIconText (i18n ("Create"));
 
     ed           = editAction ("edit_any", EDIT_ANY,
                                i18n ("&Edit Level..."),
                                i18n ("Edit level..."),
                                i18n ("Edit any level..."));
-    ed->setIcon (KIcon ("document-open"));
+    ed->setIcon (KIcon ( QLatin1String( "document-open" )));
     ed->setIconText (i18n ("Edit"));
 
     // Save Edits...
@@ -328,7 +326,7 @@ void KGoldrunner::setupActions()
                                i18n ("&Save Edits..."),
                                i18n ("Save edits..."),
                                i18n ("Save your level after editing..."));
-    saveEdits->setIcon (KIcon ("document-save"));
+    saveEdits->setIcon (KIcon ( QLatin1String( "document-save" )));
     saveEdits->setIconText (i18n ("Save"));
     saveEdits->setEnabled (false);		// Nothing to save, yet.
 
@@ -380,24 +378,20 @@ void KGoldrunner::setupActions()
                         (this, SLOT (viewFullScreen (bool)), this, this);
     actionCollection()->addAction (fullScreen->objectName(), fullScreen);
 
-    // Sound effects on/off
 #ifdef ENABLE_SOUND_SUPPORT
+    // Sound effects on/off
                                   settingAction ("options_sounds", PLAY_SOUNDS,
                                   i18n ("&Play Sounds"),
                                   i18n ("Play sound effects."),
                                   i18n ("Play sound effects during the game."));
-    // Sounds and Checked state are further initialised in game->initGame().
 #endif
 
     // Demo at start on/off.
-    KToggleAction * setDemo     = settingAction ("options_demo", STARTUP_DEMO,
+                                  settingAction ("options_demo", STARTUP_DEMO,
                                   i18n ("&Demo At Start"),
                                   i18n ("Run a demo when the game starts."),
                                   i18n ("Run a demo when the game starts."));
 
-    bool demoOnOff = gameGroup.readEntry ("StartingDemo", true);
-    setDemo->setChecked (demoOnOff);
-
     // Mouse Controls Hero
     // Keyboard Controls Hero
     // Laptop Hybrid
@@ -416,7 +410,7 @@ void KGoldrunner::setupActions()
                                         "the hero's moves."));
 
     KToggleAction * setLaptop   = settingAction ("laptop_mode", LAPTOP,
-                                  i18n ("&Hybrid Control (Laptop)"),
+                                  i18n ("Hybrid Control (&Laptop)"),
                                   i18n ("Pointer controls hero; dig "
                                         "using keyboard."),
                                   i18n ("Use the laptop's pointer device "
@@ -428,7 +422,30 @@ void KGoldrunner::setupActions()
     controlGrp->addAction (setKeyboard);
     controlGrp->addAction (setLaptop);
     controlGrp->setExclusive (true);
-    setMouse->setChecked (true);
+
+    // Options within keyboard mode.
+    // Click key to begin moving and continue moving indefinitely.
+    // Click and hold key to begin moving: release key to stop.
+
+    KToggleAction * clickKey    = settingAction ("click_key", CLICK_KEY,
+                                  i18n ("&Click Key To Move"),
+                                  i18n ("Click Key To Move."),
+                                  i18n ("In keyboard mode, click a "
+                                        "direction-key to start moving "
+                                        "and keep on going until you "
+                                        "click another key."));
+
+    KToggleAction * holdKey     = settingAction ("hold_key", HOLD_KEY,
+                                  i18n ("&Hold Key To Move"),
+                                  i18n ("Hold Key To Move."),
+                                  i18n ("In keyboard mode, hold down a "
+                                        "direction-key to move "
+                                        "and release it to stop."));
+
+    QActionGroup * keyGrp = new QActionGroup (this);
+    keyGrp->addAction (clickKey);
+    keyGrp->addAction (holdKey);
+    keyGrp->setExclusive (true);
 
     // Normal Speed
     // Beginner Speed
@@ -440,38 +457,41 @@ void KGoldrunner::setupActions()
     KToggleAction * nSpeed      = settingAction ("normal_speed", NORMAL_SPEED,
                                   i18n ("Normal Speed"),
                                   i18n ("Set normal speed."),
-                                  i18n ("Set normal game speed (12 units)."));
+                                  i18n ("Set normal game speed."));
 
     KToggleAction * bSpeed      = settingAction ("beginner_speed",
                                   BEGINNER_SPEED,
                                   i18n ("Beginner Speed"),
                                   i18n ("Set beginners' speed."),
-                                  i18n ("Set beginners' game speed (6 units)."));
+                                  i18n ("Set beginners' game speed "
+                                        "(0.5 times normal)."));
 
     KToggleAction * cSpeed      = settingAction ("champion_speed",
                                   CHAMPION_SPEED,
                                   i18n ("Champion Speed"),
                                   i18n ("Set champions' speed."),
-                                  i18n ("Set champions' game speed (18 units).")
-                                  );
+                                  i18n ("Set champions' game speed "
+                                        "(1.5 times normal)."));
 
     a                           = gameAction ("increase_speed", INC_SPEED,
                                   i18n ("Increase Speed"),
                                   i18n ("Increase speed."),
-                                  i18n ("Increase the game speed by one unit."),
+                                  i18n ("Increase the game speed by 0.1 "
+                                        "(maximum is 2.0 times normal)."),
                                   Qt::Key_Plus);
 
     a                           = gameAction ("decrease_speed", DEC_SPEED,
                                   i18n ("Decrease Speed"),
                                   i18n ("Decrease speed."),
-                                  i18n ("Decrease the game speed by one unit."),
+                                  i18n ("Decrease the game speed by 0.1 "
+                                        "(minimum is 0.2 times normal)."),
                                   Qt::Key_Minus);
 
     QActionGroup* speedGrp = new QActionGroup (this);
     speedGrp->addAction (nSpeed);
     speedGrp->addAction (bSpeed);
     speedGrp->addAction (cSpeed);
-    nSpeed->setChecked (true);
+    speedGrp->setExclusive (true);
 
     // Configure Shortcuts...
     // --------------------------
@@ -490,11 +510,18 @@ void KGoldrunner::setupActions()
     connect (kbMapper, SIGNAL (mapped (int)), game, SLOT(kbControl (int)));
     tempMapper = kbMapper;
 
+    // The actions for the movement keys are created but disabled.  This lets
+    // keyPressEvent() come through, instead of a signal, while still allowing
+    // Settings->Configure Keys to change the key mappings.  The keyPressEvent()
+    // call is needed so that the key can be identified and matched to the
+    // corresponding keyReleaseEvent() call and make the hold-key option
+    // work correctly when two keys are held down simultaneously.
+
     keyControl ("stop",       i18n ("Stop"),       Qt::Key_Space, STAND);
-    keyControl ("move_right", i18n ("Move Right"), Qt::Key_Right, RIGHT);
-    keyControl ("move_left",  i18n ("Move Left"),  Qt::Key_Left,  LEFT);
-    keyControl ("move_up",    i18n ("Move Up"),    Qt::Key_Up,    UP);
-    keyControl ("move_down",  i18n ("Move Down"),  Qt::Key_Down,  DOWN);
+    keyControl ("move_right", i18n ("Move Right"), Qt::Key_Right, RIGHT, true);
+    keyControl ("move_left",  i18n ("Move Left"),  Qt::Key_Left,  LEFT,  true);
+    keyControl ("move_up",    i18n ("Move Up"),    Qt::Key_Up,    UP,    true);
+    keyControl ("move_down",  i18n ("Move Down"),  Qt::Key_Down,  DOWN,  true);
     keyControl ("dig_right",  i18n ("Dig Right"),  Qt::Key_C,     DIG_RIGHT);
     keyControl ("dig_left",   i18n ("Dig Left"),   Qt::Key_Z,     DIG_LEFT);
 
@@ -608,16 +635,69 @@ KToggleAction * KGoldrunner::editToolbarAction (const QString & name,
 }
 
 void KGoldrunner::keyControl (const QString & name, const QString & text,
-                              const QKeySequence & shortcut, const int code)
+                              const QKeySequence & shortcut, const int code,
+                              const bool mover)
 {
     KAction * a = actionCollection()->addAction (name);
     a->setText (text);
     a->setShortcut (shortcut);
+
+    // If this is a move-key, let keyPressEvent() through, instead of signal.
+    if (mover) {
+        a->setEnabled (false);
+    }
+    else {
+        a->setAutoRepeat (false);	// Else, prevent QAction signal repeat.
+    }
+
     connect (a, SIGNAL (triggered (bool)), tempMapper, SLOT (map()));
     tempMapper->setMapping (a, code);
     addAction (a);
 }
 
+void KGoldrunner::keyPressEvent (QKeyEvent * event)
+{
+    // For movement keys, all presses and releases are processed, thus allowing
+    // the hold-key option to work correctly when two keys are held down.
+
+    if (! identifyMoveAction (event, true)) {
+        QWidget::keyPressEvent (event);
+    }
+}
+
+void KGoldrunner::keyReleaseEvent (QKeyEvent * event)
+{
+    if (! identifyMoveAction (event, false)) {
+        QWidget::keyReleaseEvent (event);
+    }
+}
+
+bool KGoldrunner::identifyMoveAction (QKeyEvent * event, bool pressed)
+{
+    bool result = false;
+    if (! event->isAutoRepeat()) {
+        QKeySequence keystroke (event->key() + event->modifiers());
+        result = true;
+
+        if ((ACTION ("move_left"))->shortcuts().contains(keystroke)) {
+            game->kbControl (LEFT, pressed);
+        }
+        else if ((ACTION ("move_right"))->shortcuts().contains(keystroke)) {
+            game->kbControl (RIGHT, pressed);
+        }
+        else if ((ACTION ("move_up"))->shortcuts().contains(keystroke)) {
+            game->kbControl (UP, pressed);
+        }
+        else if ((ACTION ("move_down"))->shortcuts().contains(keystroke)) {
+            game->kbControl (DOWN, pressed);
+        }
+        else {
+            result = false;
+        }
+    }
+    return result;
+}
+
 void KGoldrunner::viewFullScreen (bool activation)
 {
     KToggleFullScreenAction::setFullScreen (this, activation);
@@ -905,7 +985,7 @@ bool KGoldrunner::getDirectories()
         KGrMessage::information (this, i18n ("Get Folders"),
                 i18n ("Cannot find documentation sub-folder 'en/%1/' "
                 "in area '%2' of the KDE folder ($KDEDIRS).",
-                myDir, dirs->resourceDirs ("html").join (":")));
+                myDir, dirs->resourceDirs ("html").join ( QLatin1String( ":" ))));
         // result = false;		// Don't abort if the doc is missing.
     }
     else
@@ -917,7 +997,7 @@ bool KGoldrunner::getDirectories()
         KGrMessage::information (this, i18n ("Get Folders"),
         i18n ("Cannot find system games sub-folder '%1/system/' "
         "in area '%2' of the KDE folder ($KDEDIRS).",
-         myDir, dirs->resourceDirs ("data").join (":")));
+         myDir, dirs->resourceDirs ("data").join ( QLatin1String( ":" ))));
         result = false;			// ABORT if the games data is missing.
     }
     else
@@ -930,7 +1010,7 @@ bool KGoldrunner::getDirectories()
         KGrMessage::information (this, i18n ("Get Folders"),
         i18n ("Cannot find or create user games sub-folder '%1/user/' "
         "in area '%2' of the KDE user area ($KDEHOME).",
-         myDir, dirs->resourceDirs ("data").join (":")));
+         myDir, dirs->resourceDirs ("data").join ( QLatin1String( ":" ))));
         // result = false;		// Don't abort if user area is missing.
     }
     else {
@@ -974,7 +1054,7 @@ void KGoldrunner::setupEditToolbarActions()
                                i18n ("Edit level name or hint"),
                                i18n ("Edit text for the name or hint "
                                      "of a level"));
-    ed->setIcon (KIcon ("games-hint"));
+    ed->setIcon (KIcon ( QLatin1String( "games-hint" )));
     ed->setIconText (i18n ("Name/Hint"));
 
     KToggleAction * free    = editToolbarAction ("freebg", FREE,
