@@ -136,10 +136,8 @@ KGrCanvas::~KGrCanvas()
     enemyFrames->clear();
     deleteAllSprites();
 
-    while (!borderRectangles.isEmpty())
-	delete borderRectangles.takeFirst();
-    while (!borderElements.isEmpty())
-	delete borderElements.takeFirst();
+    qDeleteAll(borderRectangles);
+    qDeleteAll(borderElements);
 
     delete playfield;
     delete tileset;
@@ -342,7 +340,7 @@ void KGrCanvas::resizeEvent (QResizeEvent * event)
     
     double w = (double) event->size().width()  / (nCellsW + border);
     double h = (double) event->size().height() / (nCellsH + border);
-    int cellSize = (w < h) ? (int) (w + 0.05) : (int) (h + 0.05);
+    int cellSize = (int) (qMin(w, h) + 0.05);
 
     imgW = cellSize;
     imgH = cellSize;
@@ -667,10 +665,9 @@ void KGrCanvas::gotGold (const int spriteId, const int i, const int j,
 
 void KGrCanvas::showHiddenLadders (const QList<int> & ladders, const int width)
 {
-    int offset, i, j;
-    foreach (offset, ladders) {
-        i = offset % width;
-        j = offset / width;
+    foreach (int offset, ladders) {
+        int i = offset % width;
+        int j = offset / width;
         paintCell (i, j, LADDER);
     }
 }
@@ -692,13 +689,8 @@ void KGrCanvas::deleteSprite (const int spriteId)
 
 void KGrCanvas::deleteAllSprites()
 {
-    KGrSprite * sprite = 0;
-    while (! sprites->isEmpty()) {
-        sprite = sprites->takeFirst();
-        if (sprite != 0) {
-            delete sprite;
-        }
-    }
+    qDeleteAll(*sprites);
+    sprites->clear();
     emptySprites = 0;
 }
 
@@ -775,10 +767,10 @@ void KGrCanvas::makeBorder ()
     int tlY = topLeft.y();
     int lw = imgW / lineDivider;		// Line width.
 
-    while (!borderRectangles.isEmpty())
-	delete borderRectangles.takeFirst();
-    while (!borderElements.isEmpty())
-	delete borderElements.takeFirst();
+    qDeleteAll(borderRectangles);
+    borderRectangles.clear();
+    qDeleteAll(borderElements);
+    borderElements.clear();
 
     // a fancy border can be specified in the SVG file; if that is unavailable,
     // a simple border can be specified in the theme properties file.
