@@ -1,5 +1,6 @@
 /*
     Copyright (C) 2002-2005, Jason Katz-Brown <jasonkb@mit.edu>
+    Copyright 2010 Stefan Majewsky <majewsky@gmx.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -17,51 +18,33 @@
 */
 
 #include "kolf.h"
-
-#include <kaction.h>
-#include <kactioncollection.h>
-#include <ktoggleaction.h>
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kdeversion.h>
-#include <kfiledialog.h>
-#include <kglobal.h>
-#include <kio/netaccess.h>
-#include <klocale.h>
-#include <kxmlguiwindow.h>
-#include <kmimetype.h>
-#include <kmessagebox.h>
-#include <kscoredialog.h>
-#include <kstandarddirs.h>
-#include <kstatusbar.h>
-#include <kstandardshortcut.h>
-#include <kstandardaction.h>
-#include <kstandardgameaction.h>
-#include <KStandardGuiItem>
-#include <kicon.h>
-#include <kselectaction.h>
-#include <kdeprintdialog.h>
-
-#include <QTimer>
-#include <QGridLayout>
-#include <QtGui/QPrinter>
-#include <QtGui/QPrintDialog>
-
-#include <stdlib.h>
-
-#include "game.h"
-#include "floater.h"
-#include "slope.h"
-#include "newgame.h"
-#include "scoreboard.h"
 #include "editor.h"
-#include "pluginloader.h"
-#include "printdialogpage.h"
+#include "landscape.h"
+#include "newgame.h"
+#include "objects.h"
+#include "obstacles.h"
+#include "scoreboard.h"
 
-Kolf::Kolf()
+#include <KActionCollection>
+#include <KFileDialog>
+#include <KIO/NetAccess>
+#include <KMessageBox>
+#include <KScoreDialog>
+#include <KSelectAction>
+#include <KStandardDirs>
+#include <KStatusBar>
+#include <KStandardAction>
+#include <KStandardGameAction>
+#include <KStandardGuiItem>
+#include <KToggleAction>
+
+#include <QGridLayout>
+#include <QTimer>
+
+KolfWindow::KolfWindow()
     : KXmlGuiWindow(0)
 {
-	setObjectName("Kolf");
+	setObjectName( QLatin1String("Kolf" ));
 	competition = false;
 	game = 0;
 	editor = 0;
@@ -71,8 +54,18 @@ Kolf::Kolf()
 
 	setupActions();
 
-	obj = new ObjectList;
-	initPlugins();
+	m_itemFactory.registerType<Kolf::Slope>("slope", i18n("Slope"));
+	m_itemFactory.registerType<Kolf::Puddle>("puddle", i18n("Puddle"));
+	m_itemFactory.registerType<Kolf::Wall>("wall", i18n("Wall"));
+	m_itemFactory.registerType<Kolf::Cup>("cup", i18n("Cup"), true); //true == addOnNewHole
+	m_itemFactory.registerType<Kolf::Sand>("sand", i18n("Sand"));
+	m_itemFactory.registerType<Kolf::Windmill>("windmill", i18n("Windmill"));
+	m_itemFactory.registerType<Kolf::BlackHole>("blackhole", i18n("Black Hole"));
+	m_itemFactory.registerType<Kolf::Floater>("floater", i18n("Floater"));
+	m_itemFactory.registerType<Kolf::Bridge>("bridge", i18n("Bridge"));
+	m_itemFactory.registerType<Kolf::Sign>("sign", i18n("Sign"));
+	m_itemFactory.registerType<Kolf::Bumper>("bumper", i18n("Bumper"));
+	//NOTE: The plugin mechanism has been removed because it is not used anyway.
 
 	filename = QString();
 	dummy = new QWidget(this);
@@ -82,20 +75,15 @@ Kolf::Kolf()
 	resize(420, 480);
 }
 
-Kolf::~Kolf()
+KolfWindow::~KolfWindow()
 {
-	// wipe out our objects
-	while (!obj->isEmpty())
-		delete obj->takeFirst();
-	delete obj;
 }
 
-void Kolf::setupActions()
+void KolfWindow::setupActions()
 {
 	// Game
 	newAction = KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
 	endAction = KStandardGameAction::end(this, SLOT(closeGame()), actionCollection());
-	//printAction = KStandardGameAction::print(this, SLOT(print()), actionCollection());
 	KStandardGameAction::quit(this, SLOT(close()), actionCollection());
 
 	saveAction = actionCollection()->addAction(KStandardAction::Save, "game_save", this, SLOT(save()));
@@ -114,17 +102,17 @@ void Kolf::setupActions()
 	highScoreAction = KStandardGameAction::highscores(this, SLOT(showHighScores()), actionCollection());
 
 	// Hole
-	editingAction = new KToggleAction(KIcon("document-properties"), i18n("&Edit"), this);
+	editingAction = new KToggleAction(KIcon( QLatin1String( "document-properties") ), i18n("&Edit"), this);
 	actionCollection()->addAction("editing", editingAction);
 	connect(editingAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	editingAction->setShortcut(Qt::CTRL+Qt::Key_E);
 	newHoleAction = actionCollection()->addAction("newhole");
-	newHoleAction->setIcon(KIcon("document-new"));
+	newHoleAction->setIcon(KIcon( QLatin1String( "document-new" )));
 	newHoleAction->setText(i18n("&New"));
 	connect(newHoleAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	newHoleAction->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_N);
 	clearHoleAction = actionCollection()->addAction("clearhole");
-	clearHoleAction->setIcon(KIcon("edit-clear-locationbar-ltr"));
+	clearHoleAction->setIcon(KIcon( QLatin1String( "edit-clear-locationbar-ltr" )));
 	clearHoleAction->setText(KStandardGuiItem::clear().text());
 	connect(clearHoleAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	clearHoleAction->setShortcut(Qt::CTRL+Qt::Key_Delete);
@@ -142,17 +130,17 @@ void Kolf::setupActions()
 	actionCollection()->addAction("switchhole", holeAction);
 	connect(holeAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	nextAction = actionCollection()->addAction("nexthole");
-	nextAction->setIcon(KIcon("go-next"));
+	nextAction->setIcon(KIcon( QLatin1String( "go-next" )));
 	nextAction->setText(i18n("&Next Hole"));
 	connect(nextAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	nextAction->setShortcuts(KStandardShortcut::shortcut(KStandardShortcut::Forward));
 	prevAction = actionCollection()->addAction("prevhole");
-	prevAction->setIcon(KIcon("go-previous"));
+	prevAction->setIcon(KIcon( QLatin1String( "go-previous" )));
 	prevAction->setText(i18n("&Previous Hole"));
 	connect(prevAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	prevAction->setShortcuts(KStandardShortcut::shortcut(KStandardShortcut::Back));
 	firstAction = actionCollection()->addAction("firsthole");
-	firstAction->setIcon(KIcon("go-home"));
+	firstAction->setIcon(KIcon( QLatin1String( "go-home" )));
 	firstAction->setText(i18n("&First Hole"));
 	connect(firstAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 	firstAction->setShortcuts(KStandardShortcut::shortcut(KStandardShortcut::Begin));
@@ -161,7 +149,7 @@ void Kolf::setupActions()
 	connect(lastAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	lastAction->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_End); // why not KStandardShortcut::End (Ctrl+End)?
 	randAction = actionCollection()->addAction("randhole");
-	randAction->setIcon(KIcon("go-jump"));
+	randAction->setIcon(KIcon( QLatin1String( "go-jump" )));
 	randAction->setText(i18n("&Random Hole"));
 	connect(randAction, SIGNAL(triggered(bool)), SLOT(emptySlot()));
 
@@ -179,7 +167,7 @@ void Kolf::setupActions()
 	connect(useAdvancedPuttingAction, SIGNAL(toggled(bool)), this, SLOT(useAdvancedPuttingChanged(bool)));
 	useAdvancedPuttingAction->setChecked(configGroup.readEntry("useAdvancedPutting", false));
 
-	showInfoAction = new KToggleAction(KIcon("help-about"), i18n("Show &Info"), this);
+	showInfoAction = new KToggleAction(KIcon( QLatin1String( "help-about")), i18n("Show &Info"), this);
 	actionCollection()->addAction("showinfo", showInfoAction);
 	connect(showInfoAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
 	showInfoAction->setShortcut(Qt::CTRL+Qt::Key_I);
@@ -202,15 +190,6 @@ void Kolf::setupActions()
 	connect(soundAction, SIGNAL(toggled(bool)), this, SLOT(soundChanged(bool)));
 	soundAction->setChecked(configGroup.readEntry("sound", true));
 
-	//There are no external plugins in 4.0 and no ported instructions on how to write them
-	//Plugins will still be loaded at startup IF one is made, but reduce interface options for now
-	//QAction *action = actionCollection()->addAction("reloadplugins");
-	//action->setText(i18n("&Reload Plugins"));
-	//connect(action, SIGNAL(triggered(bool) ), SLOT(initPlugins()));
-	//action = actionCollection()->addAction("showplugins");
-	//action->setText(i18n("Show &Plugins"));
-	//connect(action, SIGNAL(triggered(bool) ), SLOT(showPlugins()));
-
 	aboutAction = actionCollection()->addAction("aboutcourse");
 	aboutAction->setText(i18n("&About Course"));
 	connect(aboutAction, SIGNAL(triggered(bool) ), SLOT(emptySlot()));
@@ -221,7 +200,7 @@ void Kolf::setupActions()
 	setupGUI();
 }
 
-bool Kolf::queryClose()
+bool KolfWindow::queryClose()
 {
 	if (game)
 		if (game->askSave(true))
@@ -229,7 +208,7 @@ bool Kolf::queryClose()
 	return true;
 }
 
-void Kolf::startNewGame()
+void KolfWindow::startNewGame()
 {
 	NewGameDialog *dialog = 0;
 	int firstHole = 1;
@@ -288,7 +267,7 @@ void Kolf::startNewGame()
 	delete spacer;
 	spacer = 0;
 	delete game;
-	game = new KolfGame(obj, &players, filename, dummy);
+	game = new KolfGame(m_itemFactory, &players, filename, dummy);
 	game->setStrict(competition);
 
 	connect(game, SIGNAL(newHole(int)), scoreboard, SLOT(newHole(int)));
@@ -343,7 +322,6 @@ void Kolf::startNewGame()
 	setHoleOtherEnabled(true);
 	aboutAction->setEnabled(true);
 	highScoreAction->setEnabled(true);
-	//printAction->setEnabled(true);
 	saveAction->setEnabled(true);
 	saveAsAction->setEnabled(true);
 	saveGameAction->setEnabled(true);
@@ -363,14 +341,14 @@ void Kolf::startNewGame()
 	delete dialog;
 }
 
-void Kolf::newGame()
+void KolfWindow::newGame()
 {
 	isTutorial = false;
 	filename = QString();
 	startNewGame();
 }
 
-void Kolf::tutorial()
+void KolfWindow::tutorial()
 {
 	QString newfilename = KGlobal::dirs()->findResource("appdata", "tutorial.kolfgame");
 	if (newfilename.isNull())
@@ -385,7 +363,7 @@ void Kolf::tutorial()
 	loadedGame = QString();
 }
 
-void Kolf::closeGame()
+void KolfWindow::closeGame()
 {
 	if (game)
 	{
@@ -406,7 +384,6 @@ void Kolf::closeGame()
 	endAction->setEnabled(false);
 	aboutAction->setEnabled(false);
 	highScoreAction->setEnabled(false);
-	//printAction->setEnabled(false);
 	saveAction->setEnabled(false);
 	saveAsAction->setEnabled(false);
 	saveGameAction->setEnabled(false);
@@ -426,7 +403,7 @@ void Kolf::closeGame()
 	QTimer::singleShot(100, this, SLOT(createSpacer()));
 }
 
-void Kolf::createSpacer()
+void KolfWindow::createSpacer()
 {
 	// make a player to play the spacer hole
 	spacerPlayers.clear();
@@ -436,7 +413,7 @@ void Kolf::createSpacer()
 	spacerPlayers.last().setId(1);
 
 	delete spacer;
-	spacer = new KolfGame(obj, &spacerPlayers, KGlobal::dirs()->findResource("appdata", "intro"), dummy);
+	spacer = new KolfGame(m_itemFactory, &spacerPlayers, KGlobal::dirs()->findResource("appdata", "intro"), dummy);
 	spacer->setSound(false);
 	layout->addWidget(spacer, 0, 0);//, Qt::AlignCenter);
 	spacer->ignoreEvents(true);
@@ -446,7 +423,7 @@ void Kolf::createSpacer()
 	spacer->hidePutter();
 }
 
-void Kolf::gameOver()
+void KolfWindow::gameOver()
 {
 	int curPar = 0;
 	int lowScore = INT_MAX; // let's hope it doesn't stay this way!
@@ -498,7 +475,7 @@ void Kolf::gameOver()
 	{
 		if (names.count() > 1)
 		{
-			QString winners = names.join(i18n(" and "));
+			QString winners = names.join( i18n(" and " ));
 			KMessageBox::information(this, i18n("%1 tied", winners));
 		}
 		else
@@ -535,7 +512,7 @@ void Kolf::gameOver()
 	QTimer::singleShot(700, this, SLOT(closeGame()));
 }
 
-void Kolf::showHighScores()
+void KolfWindow::showHighScores()
 {
 	KScoreDialog *scoreDialog = new KScoreDialog(KScoreDialog::Name | KScoreDialog::Custom1 | KScoreDialog::Score, this);
 	scoreDialog->addField(KScoreDialog::Custom1, i18n("Par"), "Par");
@@ -548,7 +525,7 @@ void Kolf::showHighScores()
 	scoreDialog->show();
 }
 
-void Kolf::save()
+void KolfWindow::save()
 {
 	if (filename.isNull())
 	{
@@ -562,7 +539,7 @@ void Kolf::save()
 	}
 }
 
-void Kolf::saveAs()
+void KolfWindow::saveAs()
 {
 	QString newfilename = KFileDialog::getSaveFileName( KUrl("kfiledialog:///kourses"),
                                   "application/x-kourse", this, i18n("Pick Kolf Course to Save To"));
@@ -575,7 +552,7 @@ void Kolf::saveAs()
 	}
 }
 
-void Kolf::saveGameAs()
+void KolfWindow::saveGameAs()
 {
 	QString newfilename = KFileDialog::getSaveFileName( KUrl("kfiledialog:///savedkolf"),
                                     "application/x-kolf", this, i18n("Pick Saved Game to Save To"));
@@ -587,7 +564,7 @@ void Kolf::saveGameAs()
 	saveGame();
 }
 
-void Kolf::saveGame()
+void KolfWindow::saveGame()
 {
 	if (loadedGame.isNull())
 	{
@@ -606,7 +583,7 @@ void Kolf::saveGame()
 	configGroup.sync();
 }
 
-void Kolf::loadGame()
+void KolfWindow::loadGame()
 {
 	loadedGame = KFileDialog::getOpenFileName( KUrl("kfiledialog:///savedkolf"),
 			 QLatin1String("application/x-kolf"), this, i18n("Pick Kolf Saved Game"));
@@ -619,7 +596,7 @@ void Kolf::loadGame()
 }
 
 // called by main for command line files
-void Kolf::openUrl(KUrl url)
+void KolfWindow::openUrl(KUrl url)
 {
 	QString target;
 	if (KIO::NetAccess::download(url, target, this))
@@ -642,7 +619,7 @@ void Kolf::openUrl(KUrl url)
 		closeGame();
 }
 
-void Kolf::newPlayersTurn(Player *player)
+void KolfWindow::newPlayersTurn(Player *player)
 {
 	tempStatusBarText = i18n("%1's turn", player->name());
 
@@ -654,7 +631,7 @@ void Kolf::newPlayersTurn(Player *player)
 	scoreboard->setCurrentCell(player->id() - 1, game->currentHole() - 1);
 }
 
-void Kolf::newStatusText(const QString &text)
+void KolfWindow::newStatusText(const QString &text)
 {
 	if (text.isEmpty())
 		statusBar()->showMessage(tempStatusBarText);
@@ -662,14 +639,14 @@ void Kolf::newStatusText(const QString &text)
 		statusBar()->showMessage(text);
 }
 
-void Kolf::editingStarted()
+void KolfWindow::editingStarted()
 {
 	delete editor;
-	editor = new Editor(obj, dummy);
-	editor->setObjectName( "Editor" );
-	connect(editor, SIGNAL(addNewItem(Object *)), game, SLOT(addNewObject(Object *)));
+	editor = new Editor(m_itemFactory, dummy);
+	editor->setObjectName( QLatin1String( "Editor" ) );
+	connect(editor, SIGNAL(addNewItem(QString)), game, SLOT(addNewObject(QString)));
 	connect(editor, SIGNAL(changed()), game, SLOT(setModified()));
-	connect(editor, SIGNAL(addNewItem(Object *)), this, SLOT(setHoleFocus()));
+	connect(editor, SIGNAL(addNewItem(QString)), this, SLOT(setHoleFocus()));
 	connect(game, SIGNAL(newSelectedItem(CanvasItem *)), editor, SLOT(setItem(CanvasItem *)));
 
 	scoreboard->hide();
@@ -684,7 +661,7 @@ void Kolf::editingStarted()
 	game->setFocus();
 }
 
-void Kolf::editingEnded()
+void KolfWindow::editingEnded()
 {
 	delete editor;
 	editor = 0;
@@ -700,26 +677,26 @@ void Kolf::editingEnded()
 		game->setFocus();
 }
 
-void Kolf::inPlayStart()
+void KolfWindow::inPlayStart()
 {
 	setEditingEnabled(false);
 	setHoleOtherEnabled(false);
 	setHoleMovementEnabled(false);
 }
 
-void Kolf::inPlayEnd()
+void KolfWindow::inPlayEnd()
 {
 	setEditingEnabled(true);
 	setHoleOtherEnabled(true);
 	setHoleMovementEnabled(true);
 }
 
-void Kolf::maxStrokesReached(const QString &name)
+void KolfWindow::maxStrokesReached(const QString &name)
 {
 	KMessageBox::sorry(this, i18n("%1's score has reached the maximum for this hole.", name));
 }
 
-void Kolf::updateHoleMenu(int largest)
+void KolfWindow::updateHoleMenu(int largest)
 {
 	QStringList items;
 	for (int i = 1; i <= largest; ++i)
@@ -731,7 +708,7 @@ void Kolf::updateHoleMenu(int largest)
 	holeAction->setEnabled(shouldbe);
 }
 
-void Kolf::setHoleMovementEnabled(bool yes)
+void KolfWindow::setHoleMovementEnabled(bool yes)
 {
 	if (competition)
 		yes = false;
@@ -745,7 +722,7 @@ void Kolf::setHoleMovementEnabled(bool yes)
 	randAction->setEnabled(yes);
 }
 
-void Kolf::setHoleOtherEnabled(bool yes)
+void KolfWindow::setHoleOtherEnabled(bool yes)
 {
 	if (competition)
 		yes = false;
@@ -755,143 +732,59 @@ void Kolf::setHoleOtherEnabled(bool yes)
 	//replayShotAction->setEnabled(yes);
 }
 
-void Kolf::setEditingEnabled(bool yes)
+void KolfWindow::setEditingEnabled(bool yes)
 {
 	editingAction->setEnabled(competition? false : yes);
 }
 
-void Kolf::checkEditing()
+void KolfWindow::checkEditing()
 {
 	editingAction->setChecked(true);
 }
 
-void Kolf::print()
-{
-	if (!game)
-		return;
-
-	QPrinter pr;
-	PrintDialogPage prPage;
-
-	QPrintDialog *printDialog = KdePrint::createPrintDialog(&pr, QList<QWidget*>() << &prPage, this);
-	printDialog->setWindowTitle(i18n("Print %1 - Hole %2", game->courseName(), game->currentHole()));
-
-	if (printDialog->exec())
-	{
-		pr.newPage();
-		game->print(pr, prPage.printTitle());
-	}
-	delete printDialog;
-}
-
-void Kolf::updateModified(bool mod)
+void KolfWindow::updateModified(bool mod)
 {
 	courseModified = mod;
 	titleChanged(title);
 }
 
-void Kolf::titleChanged(const QString &newTitle)
+void KolfWindow::titleChanged(const QString &newTitle)
 {
 	title = newTitle;
 	setCaption(title, courseModified);
 }
 
-void Kolf::useMouseChanged(bool yes)
+void KolfWindow::useMouseChanged(bool yes)
 {
 	KConfigGroup configGroup(KGlobal::config(), "Settings"); configGroup.writeEntry("useMouse", yes); configGroup.sync();
 }
 
-void Kolf::useAdvancedPuttingChanged(bool yes)
+void KolfWindow::useAdvancedPuttingChanged(bool yes)
 {
 	KConfigGroup configGroup(KGlobal::config(), "Settings"); configGroup.writeEntry("useAdvancedPutting", yes); configGroup.sync();
 }
 
-void Kolf::showInfoChanged(bool yes)
+void KolfWindow::showInfoChanged(bool yes)
 {
 	KConfigGroup configGroup(KGlobal::config(), "Settings"); configGroup.writeEntry("showInfo", yes); configGroup.sync();
 }
 
-void Kolf::showGuideLineChanged(bool yes)
+void KolfWindow::showGuideLineChanged(bool yes)
 {
 	KConfigGroup configGroup(KGlobal::config(), "Settings"); configGroup.writeEntry("showGuideLine", yes); configGroup.sync();
 }
 
-void Kolf::soundChanged(bool yes)
+void KolfWindow::soundChanged(bool yes)
 {
 	KConfigGroup configGroup(KGlobal::config(), "Settings"); configGroup.writeEntry("sound", yes); configGroup.sync();
 }
 
-void Kolf::initPlugins()
-{
-	//kDebug(12007) << "initPlugins";
-	if (game)
-		game->pause();
-
-	while (!obj->isEmpty())
-		delete obj->takeFirst();
-	plugins.clear();
-
-	// add prefab objects
-	obj->append(new SlopeObj());
-	obj->append(new PuddleObj());
-	obj->append(new WallObj());
-	obj->append(new CupObj());
-	obj->append(new SandObj());
-	obj->append(new WindmillObj());
-	obj->append(new BlackHoleObj());
-	obj->append(new FloaterObj());
-	obj->append(new BridgeObj());
-	obj->append(new SignObj());
-	obj->append(new BumperObj());
-
-	ObjectList *other = PluginLoader::loadAll();
-	QList<Object *>::const_iterator object;
-	for (object = other->constBegin(); object != other->constEnd(); ++object)
-	{
-		obj->append(*object);
-		plugins.append(*object);
-	}
-
-	if (game)
-	{
-		game->setObjects(obj);
-		game->unPause();
-	}
-
-	//kDebug(12007) << "end of initPlugins";
-}
-
-void Kolf::showPlugins()
-{
-	QString text = QString("<h2>%1</h2><ol>").arg(i18n("Currently Loaded Plugins"));
-	QList<Object *>::const_iterator object;
-        for (object = plugins.constBegin(); object != plugins.constEnd(); ++object)
-	{
-		text.append("<li>");
-		text.append((*object)->name());
-		text.append(" - ");
-		text.append(i18n("by %1", (*object)->author()));
-		text.append("</li>");
-	}
-	/*Object *object = 0;
-	for (object = plugins.first(); object; object = plugins.next())
-	{
-		text.append("<li>");
-		text.append(object->name());
-		text.append(" - ");
-		text.append(i18n("by %1", object->author()));
-		text.append("</li>");
-	}*/
-	text.append("</ol>");
-	KMessageBox::information(this, text, i18n("Plugins"));
-}
-
-void Kolf::enableAllMessages()
+void KolfWindow::enableAllMessages()
 {
 	KMessageBox::enableAllMessages();
 }
 
-void Kolf::setCurrentHole(int hole)
+void KolfWindow::setCurrentHole(int hole)
 {
 	if (!holeAction || holeAction->items().count() < hole)
 		return;
