@@ -40,8 +40,6 @@
 #include "speeds.h"
 #include "patsolve/golfsolver.h"
 
-#include "Shuffle"
-
 #include <KLocale>
 
 
@@ -50,7 +48,7 @@ void Golf::initialize()
     const qreal dist_x = 1.11;
     const qreal smallNeg = -1e-6;
 
-    static_cast<KStandardCardDeck*>( deck() )->setDeckContents();
+    setDeckContents();
 
     talon = new PatPile( this, 0, "talon" );
     talon->setPileRole(PatPile::Stock);
@@ -64,7 +62,8 @@ void Golf::initialize()
     waste->setPileRole(PatPile::Foundation);
     waste->setLayoutPos(1.1, smallNeg);
     waste->setSpread(0.12, 0);
-    waste->setReservedSpace( 0, 0, 1 + 5 * dist_x, 1 );
+    waste->setRightPadding( 5 * dist_x );
+    waste->setWidthPolicy( KCardPile::GrowRight );
     waste->setKeyboardSelectHint( KCardPile::NeverFocus );
     waste->setKeyboardDropHint( KCardPile::AutoFocusTop );
 
@@ -75,7 +74,8 @@ void Golf::initialize()
         stack[r]->setLayoutPos(r*dist_x,0);
         // Manual tweak of the pile z values to make some animations better.
         stack[r]->setZValue((7-r)/100.0);
-        stack[r]->setReservedSpace( 0, 0, 1, 2.3 );
+        stack[r]->setBottomPadding( 1.3 );
+        stack[r]->setHeightPolicy( KCardPile::GrowDown );
         stack[r]->setKeyboardSelectHint( KCardPile::AutoFocusTop );
         stack[r]->setKeyboardDropHint( KCardPile::NeverFocus );
     }
@@ -90,8 +90,8 @@ void Golf::initialize()
 bool Golf::checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const
 {
     return pile->pileRole() == PatPile::Foundation
-           && ( getRank( newCards.first() ) == getRank( oldCards.last() ) + 1
-                || getRank( newCards.first() ) == getRank( oldCards.last() ) - 1 );
+           && ( newCards.first()->rank() == oldCards.last()->rank() + 1
+                || newCards.first()->rank() == oldCards.last()->rank() - 1 );
 }
 
 
@@ -102,17 +102,17 @@ bool Golf::checkRemove(const PatPile * pile, const QList<KCard*> & cards) const
 }
 
 
-void Golf::restart()
+void Golf::restart( const QList<KCard*> & cards )
 {
-    QList<KCard*> cards = shuffled( deck()->cards(), gameNumber() );
+    QList<KCard*> cardList = cards;
 
     for ( int i = 0; i < 5; ++i )
         for ( int r = 0; r < 7; ++r )
-            addCardForDeal( stack[r], cards.takeLast(), true, stack[6]->pos() );
+            addCardForDeal( stack[r], cardList.takeLast(), true, stack[6]->pos() );
 
-    while ( !cards.isEmpty() )
+    while ( !cardList.isEmpty() )
     {
-        KCard * c = cards.takeFirst();
+        KCard * c = cardList.takeFirst();
         c->setPos( talon->pos() );
         c->setFaceUp( false );
         talon->add( c );
