@@ -299,12 +299,19 @@ bool Klondike::drop()
 
 void Klondike::mapOldId(int id)
 {
-   switch (id) {
-   case DealerInfo::KlondikeDrawThreeId :
-       setEasy( false );
-   case DealerInfo::KlondikeDrawOneId :
-       setEasy( true );
-   }
+    switch ( id )
+    {
+    case DealerInfo::KlondikeDrawOneId:
+        setEasy( true );
+        break;
+    case DealerInfo::KlondikeDrawThreeId:
+        setEasy( false );
+        break;
+    case DealerInfo::KlondikeGeneralId:
+    default:
+        // Do nothing.
+        break;
+    }
 }
 
 
@@ -325,8 +332,8 @@ public:
     KlondikeDealerInfo()
       : DealerInfo(I18N_NOOP("Klondike"), DealerInfo::KlondikeGeneralId)
     {
-        addSubtype( KlondikeDrawThreeId, I18N_NOOP( "Klondike (Draw 1)" ) );
-        addSubtype( KlondikeDrawOneId, I18N_NOOP( "Klondike (Draw 3)" ) );
+        addSubtype( KlondikeDrawOneId, I18N_NOOP( "Klondike (Draw 1)" ) );
+        addSubtype( KlondikeDrawThreeId, I18N_NOOP( "Klondike (Draw 3)" ) );
     }
 
     virtual DealerScene *createGame() const
