@@ -36,11 +36,13 @@
 
 #include "dealer.h"
 #include "dealerinfo.h"
-#include "carddeck.h"
-#include "version.h"
 #include "mainwindow.h"
+#include "version.h"
 #include "patsolve/patsolve.h"
 
+#include "KCardTheme"
+#include "KCardDeck"
+
 #include <KAboutData>
 #include <KApplication>
 #include <KCmdLineArgs>
@@ -53,32 +55,30 @@
 
 #include <QtCore/QFile>
 #include <QtCore/QTime>
-#include <QtCore/QTimer>
 #include <QtGui/QResizeEvent>
 #include <QtXml/QDomDocument>
 
-#include <cstdio>
 #include <climits>
 
 
-static const char description[] = I18N_NOOP("KDE Patience Game");
-
 static DealerScene *getDealer( int wanted_game )
 {
-    DealerInfo *di = 0;
-    for (QList<DealerInfo*>::ConstIterator it = DealerInfoList::self()->games().begin();
-         it != DealerInfoList::self()->games().end(); ++it)
+    foreach ( DealerInfo * di, DealerInfoList::self()->games() )
     {
-        if ( (*it)->ids().contains(wanted_game) ) {
-            di = *it;
-            DealerScene *f = di->createGame();
-            if ( !f || !f->solver() ) {
-                kError() << "There is no solver for" << di->name();
+        if ( di->providesId( wanted_game ) )
+        {
+            DealerScene * d = di->createGame();
+            Q_ASSERT( d );
+            d->setDeck( new KCardDeck( KCardTheme(), d ) );
+            d->initialize();
+
+            if ( !d->solver() )
+            {
+                kError() << "There is no solver for" << di->nameForId( wanted_game );;
                 return 0;
             }
 
-            fprintf( stdout, "Testing %s\n", di->name() );
-            return f;
+            return d;
         }
     }
     return 0;
@@ -98,46 +98,18 @@ QString lowerAlphaNum( const QString & string )
     return result;
 }
 
-// A function that forces all pending resize events to happen immediately.
-// Used to prevent expensive resize events after the scene has been created.
-void sendAllPendingResizeEvents( QWidget * widget )
-{
-    bool foundOne;
-    do
-    {
-        foundOne = false;
-        QList<QWidget *> allChildWidgets = widget->findChildren<QWidget *>();
-        allChildWidgets.prepend( widget );
-        foreach( QWidget* w, allChildWidgets )
-        {
-            if ( w->testAttribute(Qt::WA_PendingResizeEvent) )
-            {
-                QResizeEvent e(w->size(), QSize());
-                QApplication::sendEvent(w, &e);
-                w->setAttribute(Qt::WA_PendingResizeEvent, false);
-                // hack: make QTabWidget think it's visible; no layout otherwise
-                w->setAttribute(Qt::WA_WState_Visible, true);
-                foundOne = true;
-            }
-        }
-        // Process LayoutRequest events, in particular
-        qApp->sendPostedEvents();
-
-        if ( !foundOne )
-        {
-            // Reset visible flag, to avoid crashes in qt
-            foreach( QWidget* w, allChildWidgets )
-                w->setAttribute(Qt::WA_WState_Visible, false);
-        }
-    } while ( foundOne );
-}
 
 int main( int argc, char **argv )
 {
-    KAboutData aboutData( "kpat", 0, ki18n("KPatience"),
-                          KPAT_VERSION, ki18n(description), KAboutData::License_GPL_V2,
+    KAboutData aboutData( "kpat",
+                          0,
+                          ki18n("KPatience"),
+                          KPAT_VERSION,
+                          ki18n("KDE Patience Game"),
+                          KAboutData::License_GPL_V2,
                           ki18n("© 1995 Paul Olav Tvete\n© 2000 Stephan Kulow"),
-                          KLocalizedString(), "http://games.kde.org/kpat" );
+                          KLocalizedString(),
+                          "http://games.kde.org/kpat" );
 
     aboutData.addAuthor( ki18n("Paul Olav Tvete"),
                          ki18n("Author of original Qt version"),
@@ -183,7 +155,7 @@ int main( int argc, char **argv )
                          "simon.huerlimann@huerlisi.ch" );
     aboutData.addAuthor( ki18n("Parker Coates"),
                          ki18n("Cleanup and polish"),
-                         "parker.coates@gmail.com" );
+                         "parker.coates@kdemail.net" );
 
     // Create a KLocale earlier than normal so that we can use i18n to translate
     // the names of the game types in the help text.
@@ -192,12 +164,14 @@ int main( int argc, char **argv )
     QStringList gameList;
     foreach ( const DealerInfo *di, DealerInfoList::self()->games() )
     {
-        const QString translatedKey = lowerAlphaNum( ki18n( di->name() ).toString(tmpLocale) );
+        KLocalizedString localizedKey = ki18n( di->untranslatedBaseName().constData() );
+        const QString translatedKey = lowerAlphaNum( localizedKey.toString( tmpLocale ) );
         gameList << translatedKey;
-        indexMap.insert( translatedKey, di->ids().first() );
-        indexMap.insert( lowerAlphaNum( QString( di->name() ) ), di->ids().first() );
+        indexMap.insert( translatedKey, di->baseId() );
+        indexMap.insert( lowerAlphaNum( QString::fromUtf8( di->untranslatedBaseName() ) ), di->baseId() );
     }
     gameList.sort();
+    const QString listSeparator = ki18nc( "List separator", ", " ).toString( tmpLocale );
     delete tmpLocale;
 
     KCmdLineArgs::init( argc, argv, &aboutData );
@@ -207,13 +181,13 @@ int main( int argc, char **argv )
     options.add("solve <num>", ki18n("Dealer to solve (debug)" ));
     options.add("start <num>", ki18n("Game range start (default 0:INT_MAX)" ));
     options.add("end <num>", ki18n("Game range end (default start:start if start given)" ));
-    options.add("gametype <game>", ki18n("Skip the selection screen and load a particular game type. Valid values are: %1").subs(gameList.join(i18nc("List separator", ", "))));
+    options.add("gametype <game>", ki18n("Skip the selection screen and load a particular game type. Valid values are: %1").subs(gameList.join(listSeparator)));
     options.add("+file", ki18n("File to load"));
     KCmdLineArgs::addCmdLineOptions (options);
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
 
     KApplication application;
-    KGlobal::locale()->insertCatalog("libkdegames");
+    KGlobal::locale()->insertCatalog( QLatin1String( "libkdegames" ));
 
     QString savegame = args->getOption( "solvegame" );
     if ( !savegame.isEmpty() )
@@ -228,9 +202,9 @@ int main( int argc, char **argv )
         f->openGame( doc );
         f->solver()->translate_layout();
         int ret = f->solver()->patsolve();
-        if ( ret == Solver::WIN )
+        if ( ret == Solver::SolutionExists )
             fprintf( stdout, "won\n");
-        else if ( ret == Solver::NOSOL )
+        else if ( ret == Solver::NoSolutionExists )
             fprintf( stdout, "lost\n" );
         else
             fprintf( stdout, "unknown\n");
@@ -269,13 +243,12 @@ int main( int argc, char **argv )
         for ( int i = start_index; i <= end_index; i++ )
         {
             mytime.start();
-            f->setGameNumber( i );
-            f->restart();
+            f->startNew( i );
             f->solver()->translate_layout();
             int ret = f->solver()->patsolve();
-            if ( ret == Solver::WIN )
+            if ( ret == Solver::SolutionExists )
                 fprintf( stdout, "%d won (%d ms)\n", i, mytime.elapsed() );
-            else if ( ret == Solver::NOSOL )
+            else if ( ret == Solver::NoSolutionExists )
                 fprintf( stdout, "%d lost (%d ms)\n", i, mytime.elapsed()  );
             else
                 fprintf( stdout, "%d unknown (%d ms)\n", i, mytime.elapsed() );
@@ -288,7 +261,6 @@ int main( int argc, char **argv )
     QFile savedState( KStandardDirs::locateLocal("appdata", saved_state_file) );
 
     MainWindow *w = new MainWindow;
-    sendAllPendingResizeEvents(w->menuBar());
     if (args->count())
     {
         if (!w->openGame(args->url(0)))
