@@ -40,8 +40,6 @@
 #include "dealerinfo.h"
 #include "patsolve/mod3solver.h"
 
-#include "Shuffle"
-
 #include <KLocale>
 
 
@@ -57,7 +55,7 @@ void Mod3::initialize()
     const qreal rightColumX = 8 * dist_x + 0.8;
 
     // This patience uses 2 deck of cards.
-    static_cast<KStandardCardDeck*>( deck() )->setDeckContents( 2 );
+    setDeckContents( 2 );
 
     talon = new PatPile( this, 0, "talon" );
     talon->setPileRole(PatPile::Stock);
@@ -70,7 +68,7 @@ void Mod3::initialize()
     aces = new PatPile( this, 50, "aces");
     aces->setPileRole(PatPile::FoundationType1);
     aces->setLayoutPos(rightColumX, 0.5);
-    aces->setReservedSpace( 0, 0, 1, 2 );
+    aces->setBottomPadding( 2.5 );
     aces->setKeyboardSelectHint( KCardPile::NeverFocus );
     aces->setKeyboardDropHint( KCardPile::ForceFocusTop );
 
@@ -89,17 +87,18 @@ void Mod3::initialize()
                 // Very tight spread makes it easy to quickly tell number of
                 // cards in each pile and we don't care about the cards beneath.
                 stack[r][c]->setSpread( 0, 0.08 );
-                stack[r][c]->setReservedSpace( 0, 0, 1, 1.23 );
+                stack[r][c]->setBottomPadding( 0.23 );
             }
             else
             {
                 stack[r][c]->setLayoutPos( dist_x * c, bottomRowY );
-                stack[r][c]->setReservedSpace( 0, 0, 1, 1.8 );
+                stack[r][c]->setBottomPadding( 0.8 );
             }
             stack[r][c]->setPileRole( r == 0 ? PatPile::FoundationType2
                                       : r == 1 ? PatPile::FoundationType3
                                       : r == 2 ? PatPile::FoundationType4
                                       : PatPile::Tableau );
+            stack[r][c]->setHeightPolicy( KCardPile::GrowDown );
             stack[r][c]->setKeyboardSelectHint( KCardPile::AutoFocusTop );
             stack[r][c]->setKeyboardDropHint( KCardPile::AutoFocusTop );
         }
@@ -112,11 +111,11 @@ void Mod3::initialize()
 bool mod3CheckAdd(int baseRank, const QList<KCard*> & oldCards, const QList<KCard*> & newCards)
 {
     if (oldCards.isEmpty())
-        return getRank( newCards.first() ) == baseRank;
+        return newCards.first()->rank() == baseRank;
     else
-        return getRank( oldCards.first() ) == baseRank
-               && getSuit( newCards.first() ) == getSuit( oldCards.last() )
-               && getRank( newCards.first() ) == getRank( oldCards.last() ) + 3;
+        return oldCards.first()->rank() == baseRank
+               && newCards.first()->suit() == oldCards.last()->suit()
+               && newCards.first()->rank() == oldCards.last()->rank() + 3;
 }
 
 bool Mod3::checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const QList<KCard*> & newCards) const
@@ -124,13 +123,13 @@ bool Mod3::checkAdd(const PatPile * pile, const QList<KCard*> & oldCards, const
     switch (pile->pileRole())
     {
     case PatPile::FoundationType1:
-        return newCards.size() == 1 && getRank( newCards.first() ) == KStandardCardDeck::Ace;
+        return newCards.size() == 1 && newCards.first()->rank() == KCardDeck::Ace;
     case PatPile::FoundationType2:
-        return mod3CheckAdd(KStandardCardDeck::Two, oldCards, newCards);
+        return mod3CheckAdd(KCardDeck::Two, oldCards, newCards);
     case PatPile::FoundationType3:
-        return mod3CheckAdd(KStandardCardDeck::Three, oldCards, newCards);
+        return mod3CheckAdd(KCardDeck::Three, oldCards, newCards);
     case PatPile::FoundationType4:
-        return mod3CheckAdd(KStandardCardDeck::Four, oldCards, newCards);
+        return mod3CheckAdd(KCardDeck::Four, oldCards, newCards);
     case PatPile::Tableau:
         return oldCards.isEmpty();
     case PatPile::Stock:
@@ -172,15 +171,10 @@ void Mod3::moveCardsToPile( QList<KCard*> cards, KCardPile * pile, int duration
 
 
 
-void Mod3::restart()
+void Mod3::restart( const QList<KCard*> & cards )
 {
-    clearHighlightedItems();
-
-    QList<KCard*> cards = shuffled( deck()->cards(), gameNumber() );
-
-    while ( !cards.isEmpty() )
+    foreach ( KCard * c, cards )
     {
-        KCard * c = cards.takeFirst();
         c->setPos( talon->pos() );
         c->setFaceUp( false );
         talon->add( c );
