@@ -30,6 +30,7 @@
 #include <QPixmap>
 #include <QGraphicsItem>
 #include <QGraphicsScene>
+#include <QXmlStreamReader>
 
 #include <kstandarddirs.h>
 #include <kglobal.h>
@@ -49,7 +50,8 @@ ONU::ONU(const QString& configDir):
   m_nationalities(),
   m_continents(),
   m_renderer(),
-  m_itemsMap()
+  m_itemsMap(),
+  m_dirty(false)
 {
 
   kDebug() << "ONU constructor: " << m_configFileName;
@@ -70,11 +72,11 @@ ONU::ONU(const QString& configDir):
   kDebug() << "ONU XML format version: " << onugroup.readEntry("format-version");
   QString formatVersion = onugroup.readEntry("format-version");
 
-  if (formatVersion != "" && formatVersion != ONU_FILE_FORMAT_VERSION)
+  if (!formatVersion.isEmpty() && formatVersion != ONU_FILE_FORMAT_VERSION)
   {
     KMessageBox::error(0,
                         i18n("Error - Invalid skin definition file format. Expected %1 and got %2",QString(ONU_FILE_FORMAT_VERSION),formatVersion) + "<br>" + m_configFileName,
-                        i18n("Error !"));
+                        i18n("Error"));
 //     exit(1);
   }
 
@@ -95,7 +97,7 @@ ONU::ONU(const QString& configDir):
 //   m_continents.resize(onugroup.readEntry("nb-continents",0));
 //    root.attribute("map");
   m_poolString = onugroup.readEntry("pool");
-  if (m_poolString == "")
+  if (m_poolString.isEmpty())
   {
     m_poolString = "Images/pool.svg";
   }
@@ -107,12 +109,13 @@ ONU::ONU(const QString& configDir):
   {
       KMessageBox::error(0, 
                          i18n("Pool filename not found\nProgram cannot continue"),
-                         i18n("Error !"));
+                         i18n("Error"));
       exit(2);
   }
   m_map = QPixmap();
   m_renderer.load(poolFileName);
   m_svgDom.load(poolFileName);
+  loadPoolIds(poolFileName);
   
   QString mapMaskFileName = m_configDir + '/' + onugroup.readEntry("map-mask");
   kDebug() << "Map mask file name init: " << mapMaskFileName;
@@ -125,13 +128,12 @@ ONU::ONU(const QString& configDir):
   {
       KMessageBox::error(0, 
                          i18n("Map mask image not found\nProgram cannot continue"),
-                         i18n("Error !"));
+                         i18n("Error"));
       exit(2);
   }
   kDebug() << "Loading map mask file: " << mapMaskFileName;
   m_countriesMask = QImage(mapMaskFileName);
 
-  SkinSpritesData::changeable().intData("fighters-flag-y-diff", onugroup.readEntry("fighters-flag-y-diff",0));
   SkinSpritesData::changeable().intData("width-between-flag-and-fighter", onugroup.readEntry("width-between-flag-and-fighter",0));
 
 
@@ -311,12 +313,7 @@ ONU::ONU(const QString& configDir):
       goal->setType(Goal::Continents);
       QList<QString> continentsList = goalGroup.readEntry("continents",QList<QString>());
       foreach(const QString& continentId, continentsList)
-      {
-        if (continentId == "")
-          goal->continents().push_back(QString());
-        else
-          goal->continents().push_back(continentId);
-      }
+        goal->continents().push_back(continentId);
     }
     else if (goalType == "player" )
     {
@@ -387,31 +384,10 @@ ONU::ONU(const QString& configDir):
 
 ONU::~ONU()
 {
-  QList<Country*>::iterator countriesIt, countriesIt_end;
-  countriesIt = m_countries.begin(); countriesIt_end = m_countries.end();
-  for (; countriesIt != countriesIt_end; countriesIt++)
-  {
-    delete *countriesIt;
-  }
-
-  QList<Nationality*>::iterator nationalitiesIt, nationalitiesIt_end;
-  nationalitiesIt = m_nationalities.begin(); nationalitiesIt_end = m_nationalities.end();
-  for (; nationalitiesIt != nationalitiesIt_end; nationalitiesIt++)
-  {
-    delete *nationalitiesIt;
-  }
-  
-  QList<Continent*>::iterator continentsIt, continentsIt_end;
-  continentsIt = m_continents.begin(); continentsIt_end = m_continents.end();
-  for (; continentsIt != continentsIt_end; continentsIt++)
-  {
-    delete *continentsIt;
-  }
-
-  foreach (Goal* goal, m_goals)
-  {
-    delete goal;
-  }
+  qDeleteAll(m_countries);
+  qDeleteAll(m_nationalities);
+  qDeleteAll(m_continents);
+  qDeleteAll(m_goals);
 }
 
 void ONU::saveConfig(const QString& configFileName)
@@ -436,7 +412,6 @@ void ONU::saveConfig(const QString& configFileName)
   onugroup.writeEntry("desc",m_description);
   onugroup.writeEntry("pool",m_poolString);
 
-  onugroup.writeEntry("fighters-flag-y-diff", SkinSpritesData::changeable().intData("fighters-flag-y-diff"));
   onugroup.writeEntry("width-between-flag-and-fighter",SkinSpritesData::changeable().intData("width-between-flag-and-fighter"));
 
 
@@ -618,6 +593,7 @@ void ONU::saveConfig(const QString& configFileName)
     countryGroup.writeEntry("neighbours",theNeighboursIds);
   }
 
+  m_dirty = false;
   kDebug() << "OUT";
 }
 
@@ -801,20 +777,32 @@ QFont ONU::backgroundFont()
 
 void ONU::setFont(const QFont& font)
 {
+  if (m_font.family == font.family()
+      && m_font.size == font.pointSize()
+      && m_font.weight == (QFont::Weight)font.weight()
+      && m_font.italic == font.italic())
+    return;
   m_font.family = font.family();
   m_font.size = font.pointSize();
   m_font.weight = (QFont::Weight)font.weight();
   m_font.italic = font.italic();
+  m_dirty = true;
 }
 
 void ONU::setFontFgColor(const QColor& color)
 {
+  if (m_font.foregroundColor == color.name())
+    return;
   m_font.foregroundColor = color.name();
+  m_dirty = true;
 }
 
 void ONU::setFontBgColor(const QColor& color)
 {
+  if (m_font.backgroundColor == color.name())
+    return;
   m_font.backgroundColor = color.name();
+  m_dirty = true;
 }
 
 
@@ -823,6 +811,7 @@ void ONU::createCountry(const QString& newCountryName)
   kDebug();
   Country* newCountry = new Country(newCountryName, QPointF(), QPointF(), QPointF(), QPointF(), QPointF(), QPointF()/*, m_countries.size()*/);
   m_countries.push_back(newCountry);
+  m_dirty = true;
 }
 
 void ONU::deleteCountry(Country* country)
@@ -850,6 +839,7 @@ void ONU::deleteCountry(Country* country)
 
   m_countries.removeAll(country);
   delete country;
+  m_dirty = true;
 }
 
 void ONU::createContinent(const QString& newContinentName)
@@ -857,6 +847,7 @@ void ONU::createContinent(const QString& newContinentName)
   kDebug();
   Continent* newContinent = new Continent(newContinentName, QList<Country*>(), 0);
   m_continents.push_back(newContinent);
+  m_dirty = true;
 }
 
 void ONU::deleteContinent(Continent* continent)
@@ -868,6 +859,7 @@ void ONU::deleteContinent(Continent* continent)
   
   m_continents.removeAll(continent);
   delete continent;
+  m_dirty = true;
 }
 
 void ONU::updateIcon(SpriteType type)
@@ -938,6 +930,7 @@ void ONU::createGoal()
 {
   Goal* goal = new Goal();
   m_goals.push_back(goal);
+  m_dirty = true;
 }
 
 void ONU::deleteGoal(int g)
@@ -951,6 +944,7 @@ void ONU::deleteGoal(int g)
   
   Goal* goal = m_goals.takeAt(g);
   delete goal;
+  m_dirty = true;
 }
 
 Nationality* ONU::nationalityNamed(const QString& name)
@@ -970,6 +964,7 @@ void ONU::createNationality(const QString& newNationalityName)
   Nationality* nationality = new Nationality(newNationalityName, "", "");
   
   m_nationalities.push_back(nationality);
+  m_dirty = true;
 }
 
 void ONU::deleteNationality(Nationality* nationality)
@@ -981,6 +976,43 @@ void ONU::deleteNationality(Nationality* nationality)
   
   m_nationalities.removeAll(nationality);
   delete nationality;
+  m_dirty = true;
+}
+
+void ONU::loadPoolIds(const QString& fileName)
+{
+  kDebug() << fileName;
+  QFile file(fileName);
+  if (!file.open(QFile::ReadOnly | QFile::Text))
+  {
+    KMessageBox::sorry(0,
+                        i18n("Cannot read file %1:\n%2.",fileName,file.errorString()),
+                        i18n("PoolLoader"));
+                        return;
+  }
+  
+  QXmlStreamReader xml(&file);
+  QRegExp reg("\\D+\\d+");
+  while (!xml.atEnd())
+  {
+    QXmlStreamReader::TokenType type = xml.readNext();
+    if (type == QXmlStreamReader::StartElement)
+    {
+      kDebug() << xml.text().toString();
+      QXmlStreamAttributes attributes = xml.attributes ();
+      QStringRef id = attributes.value("", "id" );
+      if (!id.isEmpty() && !reg.exactMatch(id.toString()))
+      {
+        m_poolIds.push_back(id.toString());
+      }
+    }
+  }
+  if (xml.hasError())
+  {
+    kError() << "Error: " << xml.errorString();
+    // do error handling
+  }
+  m_poolIds.sort();
 }
 
 }
