@@ -64,12 +64,8 @@ Game::Game (Kubrick * parent)
 
 Game::~Game ()
 {
-    while (! cubeViews.isEmpty()) {
-        delete cubeViews.takeFirst();
-    }
-    while (! moves.isEmpty()) {
-        delete moves.takeFirst();
-    }
+    qDeleteAll(cubeViews);
+    qDeleteAll(moves);
 }
 
 
@@ -118,9 +114,8 @@ void Game::initGame (GameGLView * glv, Kubrick * mw)
     currentSceneID = 0;  // Forces startAnimation() to initialise the scene.
     startAnimation ("", option [optSceneID], false, false);
 
-    while (! moves.isEmpty()) {
-        delete moves.takeFirst();
-    }
+    qDeleteAll(moves);
+    moves.clear();
     shuffleMoves = 0;
     playerMoves = 0;
 
@@ -241,13 +236,13 @@ void Game::newCubeDialog ()
 
 void Game::undoMove ()
 {
-    startUndo ("u", i18n("Undo"));
+    startUndo (QChar('u'), i18n("Undo"));
 }
 
 
 void Game::redoMove ()
 {
-    startRedo ("r", i18n("Redo"));
+    startRedo (QChar('r'), i18n("Redo"));
 }
 
 
@@ -356,19 +351,19 @@ void Game::setStandardView()
 
 void Game::undoAll ()
 {
-    startUndo ("U", i18n("Restart Puzzle (Undo All)"));
+    startUndo (QChar('U'), i18n("Restart Puzzle (Undo All)"));
 }
 
 
 void Game::redoAll ()
 {
-    startRedo ("R", i18n("Redo All"));
+    startRedo (QChar('R'), i18n("Redo All"));
 }
 
 
 void Game::changeScene (const int newSceneID)
 {
-    QString sceneActionName = "scene_" + QString().setNum (newSceneID);
+    QString sceneActionName = "scene_" + QString::number(newSceneID);
     mainWindow->setToggle (sceneActionName.toLatin1().data(), true);
 
     currentSceneID = newSceneID;
@@ -559,7 +554,7 @@ void Game::addPlayersMove (Move * move)
     singmasterString.append (tempString);
 
     // Trigger the animation's advance() cycle to do the move(s).
-    startAnimation (displaySequence + "m", option [optSceneID],
+    startAnimation (displaySequence + QChar('m'), option [optSceneID],
 			option [optViewShuffle], option [optViewMoves]);
 }
 
@@ -874,7 +869,7 @@ void Game::executeSingmasterMove (const SingmasterMove smCode)
     singmasterString.append (smTempString);
 
     // Trigger the animation's advance() cycle to do the move.
-    startAnimation (displaySequence + "m", option [optSceneID],
+    startAnimation (displaySequence + QChar('m'), option [optSceneID],
 			option [optViewShuffle], option [optViewMoves]);
 
     smInitInput();			// Re-initialise the move-text parsing.
@@ -982,14 +977,11 @@ void Game::restoreState ()
 
 void Game::newCube (int xDim, int yDim, int zDim, int shMoves)
 {
-    if (cube != 0) {
-	delete cube;			// Delete the previous cube (if any).
-    }
+    delete cube;			// Delete the previous cube (if any).
     cubeSize [X] = xDim;
     cubeSize [Y] = yDim;
     cubeSize [Z] = zDim;
-    nMax = (xDim > yDim) ? xDim: yDim;
-    nMax = (zDim > nMax) ? zDim: nMax;
+    nMax = qMax(qMax(xDim, yDim), zDim);
     shuffleMoves = shMoves;
 
     cube = new Cube (this, cubeSize[X], cubeSize[Y], cubeSize[Z]);
@@ -1001,9 +993,8 @@ void Game::newCube (int xDim, int yDim, int zDim, int shMoves)
 
     moveFeedback = None;		// No move being selected.
 
-    while (! moves.isEmpty()) {		// Re-initialise the internal move-list.
-        delete moves.takeFirst();
-    }
+    qDeleteAll(moves);			// Re-initialise the internal move-list.
+    moves.clear();
     playerMoves = 0;
 
     singmasterString = "";		// Re-initialise the Singmaster moves
@@ -1015,10 +1006,10 @@ void Game::newCube (int xDim, int yDim, int zDim, int shMoves)
     smShowSingmasterMoves();
 
     // Shuffle the cube.
-    QString dSeq = "";			// No moves to do, if no shuffling.
+    QString dSeq;			// No moves to do, if no shuffling.
     if (shuffleMoves > 0) {
 	shuffleCube ();			// Calculate the shuffling moves.
-	dSeq = "h";			// Ask to do the shuffling moves.
+	dSeq = QChar('h');		// Ask to do the shuffling moves.
     }
     // Trigger the animation's advance() cycle to do the moves.
     startAnimation (dSeq, option [optSceneID], option [optViewShuffle],
@@ -1494,9 +1485,7 @@ void Game::loadPuzzle (KConfig & config)
 	mainWindow->setToggle ("watch_moves",     (bool)option[optViewMoves]);
     }
 
-    while (! moves.isEmpty()) {
-        delete moves.takeFirst();
-    }
+    qDeleteAll(moves);
     moves               = movesTemp;
     shuffleMoves	= moveCounts [0];
     playerMoves		= moveCounts [1];
@@ -1517,12 +1506,12 @@ void Game::loadPuzzle (KConfig & config)
     QString dSeq = dsTemp;
     if (dSeq.isEmpty ()) {
 	if (shuffleMoves > 0) {
-	    dSeq = "h";
+	    dSeq = QChar('h');
 	}
 	if (playerMoves > 0) {
 	    // Redo all the player moves, using "M" (not "R", Redo All, in
 	    // case there are some undone moves on the end of the list).
-	    dSeq = dSeq + "M";
+	    dSeq += QChar('M');
 	}
     }
 
@@ -1557,7 +1546,7 @@ void Game::startUndo (QString code, QString header)
 	// There is an incomplete Singmaster move, so undo that first.
 	smInitInput();
 	smShowSingmasterMoves();	// Re-display the Singmaster moves.
-	if ((playerMoves <= 0) || (code == "u")) {
+	if ((playerMoves <= 0) || (code == QChar('u'))) {
 	    return;			// The Undo or Undo All is finished.
 	}
     }
@@ -1654,10 +1643,8 @@ void Game::shuffleCube ()
     Move * prev;
     int    sliceNo;
 
-    // Empty the list of moves and delete all move objects.
-    while (! moves.isEmpty()) {
-        delete moves.takeFirst();
-    }
+    qDeleteAll(moves);
+    moves.clear();
 
     LOOP (n, shuffleMoves) {
 	move = new Move;
