@@ -20,11 +20,11 @@
 #ifndef KEXTHIGHSCORE_TAB_H
 #define KEXTHIGHSCORE_TAB_H
 
-#include <qcombobox.h>
-#include <qmemarray.h>
+#include <QtCore/QVector>
+#include <QtGui/QComboBox>
 
 class QLabel;
-class KListView;
+class QTreeWidget;
 
 
 namespace KExtHighscore
@@ -35,7 +35,7 @@ class PlayersCombo : public QComboBox
 {
  Q_OBJECT
  public:
-    PlayersCombo(QWidget *parent = 0, const char *name = 0);
+    PlayersCombo(QWidget *parent = 0);
 
     void load();
 
@@ -53,7 +53,7 @@ class AdditionalTab : public QWidget
 {
  Q_OBJECT
  public:
-    AdditionalTab(QWidget *parent, const char *name);
+    AdditionalTab(QWidget *parent);
 
     virtual void load();
 
@@ -75,7 +75,7 @@ class StatisticsTab : public AdditionalTab
 {
  Q_OBJECT
  public:
-    StatisticsTab(QWidget *parent);
+    explicit StatisticsTab(QWidget *parent);
 
     void load();
 
@@ -88,7 +88,7 @@ class StatisticsTab : public AdditionalTab
         uint count[Nb_Counts];
         double trend[Nb_Trends];
     };
-    QMemArray<Data> _data;
+    QVector<Data> _data;
     QLabel *_nbs[Nb_Counts], *_percents[Nb_Counts], *_trends[Nb_Trends];
 
     QString percent(const Data &, Count) const;
@@ -105,9 +105,9 @@ class HistogramTab : public AdditionalTab
     void load();
 
  private:
-    QMemArray<uint> _counts;
-    QMemArray<uint> _data;
-    KListView       *_list;
+    QVector<uint> _counts;
+    QVector<uint> _data;
+    QTreeWidget   *_list;
 
     void display(uint i);
 };
