@@ -31,11 +31,11 @@
 #include <knuminput.h>
 #include <kdialog.h>
 #include <kmessagebox.h>
+#include <klineedit.h>
 
 #include <QLayout>
 #include <QLabel>
 #include <QPushButton>
-#include <QLineEdit>
 #include <QGroupBox>
 
 #include "kgamedialogconfig.moc"
@@ -56,7 +56,7 @@ public:
 	KPlayer* mOwner;
 };
 
-KGameDialogConfig::KGameDialogConfig(QWidget* parent) 
+KGameDialogConfig::KGameDialogConfig(QWidget* parent)
     : QWidget( parent ),
       d( new KGameDialogConfigPrivate )
 {
@@ -149,7 +149,7 @@ KGameDialogNetworkConfig::KGameDialogNetworkConfig(QWidget* parent)
 
  // Needs to be AFTER the creation of the dialogs
  setConnected(false);
- setDefaultNetworkInfo("localhost", 7654,true);
+ setDefaultNetworkInfo(QLatin1String( "localhost" ), 7654,true);
 }
 
 KGameDialogNetworkConfig::~KGameDialogNetworkConfig()
@@ -262,7 +262,7 @@ public:
 		mName = 0;
 	}
 
-	QLineEdit* mName;
+	KLineEdit* mName;
 
 	QVBoxLayout* mTopLayout;
 };
@@ -283,7 +283,7 @@ KGameDialogGeneralConfig::KGameDialogGeneralConfig(QWidget* parent, bool initial
 	QHBoxLayout* l = new QHBoxLayout(nameWidget);
 	QLabel* nameLabel = new QLabel(i18n("Your name:"), nameWidget);
 	l->addWidget(nameLabel);
-	d->mName = new QLineEdit(nameWidget);
+	d->mName = new KLineEdit(nameWidget);
 	l->addWidget(d->mName);
  }
 }
@@ -451,7 +451,7 @@ void KGameDialogMsgServerConfig::slotChangeMaxClients()
  l->setSpacing( KDialog::spacingHint() );
 
  l->addWidget(new QLabel(i18n("Maximal number of clients (-1 = infinite):"), dialog));
- QLineEdit* edit = new QLineEdit(dialog);//TODO: use KIntNumInput
+ KLineEdit* edit = new KLineEdit(dialog);//TODO: use KIntNumInput
  l->addWidget(edit);
 // edit->setText(QString::number(max)); // current max clients! //TODO
  if (dialog->exec() == QDialog::Accepted) {
@@ -654,7 +654,8 @@ void KGameDialogConnectionConfig::setKGame(KGame* g)
 	connect(game(), SIGNAL(signalPlayerLeftGame(KPlayer*)),
 			this, SLOT(slotPlayerLeftGame(KPlayer*)));
 
-  for ( QList<KPlayer*>::const_iterator it = game()->playerList()->begin(); it!=game()->playerList()->end();it++ )
+  const QList<KPlayer*> *playerList = game()->playerList();
+  for ( QList<KPlayer*>::const_iterator it = playerList->begin(); it!=playerList->end();++it )
   {
 		slotPlayerJoinedGame(*it);
 	}
